@@ -9,7 +9,7 @@ y <- ts(c(rpois(20,0.25),rpois(20,0.5),rpois(20,1),rpois(20,2),rpois(20,3),rpois
 ## ----iETSFExample1------------------------------------------------------------
 oETSFModel1 <- oes(y, occurrence="fixed", h=10, holdout=TRUE)
 oETSFModel1
-plot(oETSFModel1, 1)
+plot(oETSFModel1)
 
 ## ----iETSFExample2------------------------------------------------------------
 es(y, "MMN", occurrence="fixed", h=10, holdout=TRUE, silent=FALSE)
@@ -17,7 +17,7 @@ es(y, "MMN", occurrence="fixed", h=10, holdout=TRUE, silent=FALSE)
 ## ----iETSOExample1------------------------------------------------------------
 oETSOModel <- oes(y, model="MMN", occurrence="o", h=10, holdout=TRUE)
 oETSOModel
-plot(oETSOModel, 1)
+plot(oETSOModel)
 
 ## ----iETSOExample2------------------------------------------------------------
 es(y, "MMN", occurrence="o", oesmodel="MMN", h=10, holdout=TRUE, silent=FALSE)
@@ -28,7 +28,7 @@ es(y, "MMN", occurrence="o", oesmodel="MMN", h=10, holdout=TRUE, silent=FALSE)
 ## ----iETSIExample1------------------------------------------------------------
 oETSIModel <- oes(y, model="MMN", occurrence="i", h=10, holdout=TRUE)
 oETSIModel
-plot(oETSIModel, 1)
+plot(oETSIModel)
 
 ## ----iETSIExample2------------------------------------------------------------
 es(y, "MMN", occurrence="i", oesmodel="MMN", h=10, holdout=TRUE, silent=FALSE)
@@ -39,7 +39,7 @@ es(y, "MMN", occurrence="i", oesmodel="MMN", h=10, holdout=TRUE, silent=FALSE)
 ## ----iETSDExample1------------------------------------------------------------
 oETSDModel <- oes(y, model="MMN", occurrence="d", h=10, holdout=TRUE)
 oETSDModel
-plot(oETSDModel, 1)
+plot(oETSDModel)
 
 ## ----iETSDExample2------------------------------------------------------------
 es(y, "MMN", occurrence=oETSDModel, h=10, holdout=TRUE, silent=FALSE)
@@ -47,12 +47,12 @@ es(y, "MMN", occurrence=oETSDModel, h=10, holdout=TRUE, silent=FALSE)
 ## ----iETSGExample1------------------------------------------------------------
 oETSGModel1 <- oesg(y, modelA="MNN", modelB="AAN", h=10, holdout=TRUE)
 oETSGModel1
-plot(oETSGModel1, 1)
+plot(oETSGModel1)
 
 ## ----iETSGExample2------------------------------------------------------------
 oETSGModel2 <- oes(y, model="MNN", occurrence="g", h=10, holdout=TRUE)
 oETSGModel2
-plot(oETSGModel2, 1)
+plot(oETSGModel2)
 
 ## ----iETSGExample3------------------------------------------------------------
 es(y, "MMN", occurrence="g", oesmodel="MMN", h=10, holdout=TRUE, silent=FALSE)
@@ -60,7 +60,7 @@ es(y, "MMN", occurrence="g", oesmodel="MMN", h=10, holdout=TRUE, silent=FALSE)
 ## ----iETSAExample1------------------------------------------------------------
 oETSAModel <- oes(y, model="MNN", occurrence="a", h=10, holdout=TRUE)
 oETSAModel
-plot(oETSAModel, 1)
+plot(oETSAModel)
 
 ## ----iETSGRoundedExample------------------------------------------------------
 es(rpois(100,0.3), "MNN", occurrence="g", oesmodel="MNN", h=10, holdout=TRUE, silent=FALSE, interval=TRUE, rounded=TRUE)
